from datetime import datetime
from typing import Optional

from pydantic import BaseModel, Field


class TodoBase(BaseModel):
    """Base schema for Todo."""

    title: str = Field(..., min_length=1, max_length=100)
    description: Optional[str] = None
    completed: bool = False


class TodoCreate(TodoBase):
    """Schema for creating a Todo."""

    pass


class TodoUpdate(BaseModel):
    """Schema for updating a Todo."""

    title: Optional[str] = Field(None, min_length=1, max_length=100)
    description: Optional[str] = None
    completed: Optional[bool] = None


class TodoInDB(TodoBase):
    """Schema for Todo stored in DB."""

    id: int
    created_at: datetime
    updated_at: datetime

    class Config:
        from_attributes = True


class TodoResponse(TodoInDB):
    """Schema for Todo response."""

    pass
